==> haskell-stringbuilder-0.5.1-66-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stringbuilder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stringbuilder
version:              0.5.1
visibility:           public
id:                   stringbuilder-0.5.1-4FToWHzIrH85G9Y43oDuE0
key:                  stringbuilder-0.5.1-4FToWHzIrH85G9Y43oDuE0
license:              MIT
copyright:            (c) 2011-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A writer monad for multi-line string literals
description:          <https://github.com/sol/stringbuilder#readme>
category:             Testing
abi:                  425872a4330e03e7b6cdaa39cf8b10b6
exposed:              True
exposed-modules:      Data.String.Builder
import-dirs:          /usr/lib/ghc-8.8.1/site-local/stringbuilder-0.5.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/stringbuilder-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/stringbuilder-0.5.1
hs-libraries:         HSstringbuilder-0.5.1-4FToWHzIrH85G9Y43oDuE0
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-stringbuilder/html/stringbuilder.haddock

haddock-html:         /usr/share/doc/haskell-stringbuilder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stringbuilder-0.5.1-70-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-stringbuilder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 stringbuilder
version:              0.5.1
visibility:           public
id:                   stringbuilder-0.5.1-Lk2QwpJQYeBJjevghXXiPv
key:                  stringbuilder-0.5.1-Lk2QwpJQYeBJjevghXXiPv
license:              MIT
copyright:            (c) 2011-2018 Simon Hengel
maintainer:           Simon Hengel <sol@typeful.net>
author:               Simon Hengel <sol@typeful.net>
synopsis:             A writer monad for multi-line string literals
description:          <https://github.com/sol/stringbuilder#readme>
category:             Testing
abi:                  49bb6f5e297147b03f28bd917bd465c5
exposed:              True
exposed-modules:      Data.String.Builder
import-dirs:          /usr/lib/ghc-8.8.1/site-local/stringbuilder-0.5.1
library-dirs:         /usr/lib/ghc-8.8.1/site-local/stringbuilder-0.5.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/stringbuilder-0.5.1
hs-libraries:         HSstringbuilder-0.5.1-Lk2QwpJQYeBJjevghXXiPv
depends:              base-4.13.0.0
haddock-interfaces:
    /usr/share/doc/haskell-stringbuilder/html/stringbuilder.haddock

haddock-html:         /usr/share/doc/haskell-stringbuilder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
